
![screenhsot](http://www.ai-z.org/assets/screenshot01.png)

### Install and usage
```
git clone https://github.com/ai-z/ai-z.git
cd ai-z
pip3 install -r requirements.txt
python3 ai-z.py
```
### Known Issues

* AMD GPUs name will be displayed as ‘cardX’
* PCIE bandwith usage graph on NVDIA cards is not correct
